@@ -59,12 +59,10 @@ def validate_profile(config: dict, arguments: argparse.Namespace, profiles: dict
 
     # validate role profiles
     if 'role_arn' in profile:
-        if profile.get('credential_process'):
-            raise exceptions.InvalidProfileError(target_profile_name, message='awsume does not support the credential_process profile option: {}')
         if profile.get('credential_source') and profile.get('source_profile'):
             raise exceptions.InvalidProfileError(target_profile_name, message='credential_source and source_profile are mutually exclusive profile options')
-        if not profile.get('credential_source') and not profile.get('source_profile') and not profile.get('principal_arn'):
-            raise exceptions.InvalidProfileError(target_profile_name, message='role profiles must contain one of credential_source or source_profile')
+        if not profile.get('credential_source') and not profile.get('credential_process') and not profile.get('source_profile') and not profile.get('principal_arn'):
+            raise exceptions.InvalidProfileError(target_profile_name, message='role profiles must contain one of credential_source or source_profile or credential_process')
         if profile.get('credential_source') not in VALID_CREDENTIAL_SOURCES:
             raise exceptions.InvalidProfileError(target_profile_name, message='unsupported awsume credential_source profile option: {}'.format(profile.get('credential_source')))
         source_profile_name = profile.get('source_profile')
@@ -87,17 +85,14 @@ def validate_profile(config: dict, arguments: argparse.Namespace, profiles: dict
         if 'credential_source' in profile:
             if profile.get('credential_source') not in VALID_CREDENTIAL_SOURCES:
                 raise exceptions.InvalidProfileError(user_profile_name, message='unsupported awsume credential_source profile option: {}'.format(profile.get('credential_source')))
-        else:
+        elif not 'credential_process' in user_profile and not 'credential_process' in profile:
             if 'aws_access_key_id' not in user_profile:
                 missing_keys.append('aws_access_key_id')
             if 'aws_secret_access_key' not in user_profile:
                 missing_keys.append('aws_secret_access_key')
         if missing_keys:
-            raise exceptions.InvalidProfileError(user_profile_name, message='Missing keys {}, or credential_source'.format(', '.join(missing_keys)))
+            raise exceptions.InvalidProfileError(user_profile_name, message='Missing keys {}, or credential_source, or credential_process'.format(', '.join(missing_keys)))
 
-    # validate arguments with profile
-    if 'role_arn' not in profile and arguments.auto_refresh:
-        raise exceptions.ValidationException('Cannot use autoawsume with non-role profile')
     return True
 
 
@@ -118,18 +113,23 @@ def get_source_profile(profiles: dict, target_profile_name: str) -> dict:
     return None
 
 
-def get_role_chain(profiles: dict, target_profile_name: str) -> list:
+def get_role_chain(config: dict, arguments: argparse.Namespace, profiles: dict, target_profile_name: str) -> list:
+    logger.debug('Getting role chain for [{}]'.format(target_profile_name))
     target_profile = profiles.get(target_profile_name)
-    if not target_profile or not target_profile.get('role_arn'):
+
+    if not target_profile or not target_profile.get('role_arn') or get_role_duration(config, arguments, target_profile):
         return [target_profile_name]
 
     role_chain = []
     while target_profile:
-        if target_profile.get('role_arn'):
-            if target_profile_name in role_chain:
-                raise exceptions.InvalidProfileError(','.join(role_chain), 'cannot have circular role-chains')
-            role_chain.append(target_profile_name)
+        logger.debug('target profile: {}'.format(json.dumps(target_profile, default=str)))
+        if target_profile_name in role_chain:
+            raise exceptions.InvalidProfileError(','.join(role_chain), 'cannot have circular role-chains')
+        role_chain.append(target_profile_name)
         target_profile_name = target_profile.get('source_profile')
+        # if mfa required on role arn, get longer 12-hour session credentials first by doing mfa on the source profile
+        if 'role_arn' in target_profile and 'mfa_serial' in target_profile:
+            profiles[target_profile_name]['mfa_serial'] = target_profile['mfa_serial']
         target_profile = profiles.get(target_profile_name)
     role_chain.reverse()
     return role_chain
@@ -153,6 +153,19 @@ def get_region(profiles: dict, arguments: argparse.Namespace, config: dict, igno
     return None
 
 
+def get_session_name(config: dict, arguments: argparse.Namespace, profiles: dict, target_profile_name: str) -> dict:
+    target_profile = profiles.get(target_profile_name)
+    if arguments.session_name:
+        return arguments.session_name
+    if target_profile and target_profile.get('role_session_name'):
+        return target_profile['role_session_name']
+    if config.get('role-session-name'):
+        return config['role-session-name']
+    if target_profile_name:
+        return target_profile_name
+    return 'awsume-session'
+
+
 def get_external_id(arguments: argparse.Namespace, target_profile: dict):
     if arguments.external_id:
         return arguments.external_id
@@ -225,7 +238,7 @@ def format_aws_profiles(profiles: dict, get_extra_data: bool) -> list: # pragma:
             else:
                 source_profile = 'None'
             mfa_needed = 'Yes' if 'mfa_serial' in profile else 'No'
-            profile_region = str(profile.get('region'))
+            profile_region = str(profile.get('region')) or str(profile.get('sso_region'))
             profile_account_id = get_account_id(profile, get_extra_data)
             list_row = [name, profile_type, source_profile, mfa_needed, profile_region, profile_account_id]
             profile_list.append(list_row)
@@ -240,14 +253,18 @@ def print_formatted_data(profile_data: list): # pragma: no cover
         print('  '.join((val.ljust(width) for val, width in zip(row, widths))))
 
 
-def list_profile_data(profiles: dict, get_extra_data: bool): # pragma: no cover
+def list_profile_data(profiles: dict, get_extra_data: bool, config: dict): # pragma: no cover
     profiles = {k: v for k, v in profiles.items() if not v.get('autoawsume')}
-    formatted_profiles = format_aws_profiles(profiles, get_extra_data)
-    print_formatted_data(formatted_profiles)
+    if config.get('is_interactive'):
+        formatted_profiles = format_aws_profiles(profiles, get_extra_data)
+        print_formatted_data(formatted_profiles)
+    return profiles
 
 
 def get_account_id(profile: dict, call_aws: bool = False) -> str:
     logger.info('Getting account ID from profile: %s', json.dumps(profile, indent=2))
+    if profile.get('sso_account_id'):
+        return profile['sso_account_id']
     if profile.get('role_arn'):
         return profile['role_arn'].replace('arn:aws:iam::', '').split(':')[0]
     if profile.get('mfa_serial'):
